﻿<%@ WebHandler Language="C#" Class="Handler" %>

using System;
using System.Web;
using System.Collections.Generic;
using C1.Web.Wijmo.Controls.C1ReportViewer;
using C1.C1Preview;
using C1.C1Preview.DataBinding;
using System.IO;
using System.Drawing;

public class Handler : IHttpHandler {

    private class ReportData
    {
        public string GroupName { get; set; }
        public string Value { get; set; }
    }
    
    public void ProcessRequest (HttpContext context) {
        var data = new List<ReportData>();

        for (var i = 0; i < 100; i++)
        {
            data.Add(new ReportData() { GroupName = "Group " + (i % 10), Value = "Demo" + i });
        }

        var doc = C1ReportViewer.CreateC1PrintDocument();
        doc.PageLayout.PageHeader = CreateHeader();

        var rt = new RenderTable();
        doc.Body.Children.Add(rt);

        var headerRow = rt.Rows[0];
        headerRow[0].Text = "Group Name/ Value";
        headerRow.Style.BackColor = Color.Blue;
        headerRow.Style.TextColor = Color.White;

        rt.RowGroups[0, 1].PageHeader = true;
        
        var groupRow = rt.Rows[1];
        groupRow[0].Text = "[Fields!GroupName.Value]";
        groupRow.Style.BackColor = Color.LightGray;

        var dataRow = rt.Rows[2];
        dataRow[0].Text = "[Fields!Value.Value]";

        var group = rt.RowGroups[1, 2];
        group.DataBinding.DataSource = data;
        group.DataBinding.Grouping.Expressions.Add("Fields!GroupName.Value");

        var agg = new Aggregate("OnGroup_GroupLevel");
        agg.ExpressionText = "Fields!GroupName.Value";
        agg.DataBinding = group.DataBinding;
        agg.Func = AggregateFuncEnum.First;
        agg.Running = RunningEnum.Group;
        rt.Document.DataSchema.Aggregates.Add(agg);
        
        agg = new Aggregate("OnGroup_DocLevel");
        agg.ExpressionText = "Fields!GroupName.Value";
        agg.DataBinding = group.DataBinding;
        agg.Func = AggregateFuncEnum.First;
        agg.Running = RunningEnum.Document;
        rt.Document.DataSchema.Aggregates.Add(agg);

        var detail = rt.RowGroups[2, 1];
        detail.DataBinding.DataSource = data;
        
        var exporter = new C1.C1Preview.Export.PdfExportProvider();
        using(var ms = new MemoryStream())
        {
            doc.Export(ms, exporter, false);
            string disposition = "inline";
            string fileName = "Demo.pdf";
            string format = "pdf";

            var response = context.Response;
            response.ContentType = "application/pdf";
            response.AddHeader("content-disposition", string.Format("{0};filename=\"{1}.{2}\"", disposition, fileName, format.ToString()));
            ms.Seek(0, SeekOrigin.Begin);
            ms.CopyTo(response.OutputStream);
        }
    }
    
    private RenderObject CreateHeader()
    {
        var rt = new RenderTable();
        var ra = new RenderArea();
        rt.Cells[0, 2].Style.TextAlignHorz = AlignHorzEnum.Right;
        rt.Cells[0, 2].RenderObject = ra;

        ra.Children.Add(new RenderText("[PageNo] of [PageCount]"));
        ra.Children.Add(new RenderText("GroupLevel: [Aggregates!OnGroup_GroupLevel.Value]"));
        ra.Children.Add(new RenderText("DocLevel: [Aggregates!OnGroup_DocLevel.Value]"));
        ra.Children.Add(new RenderText("Some try: [Aggregates!OnGroup_GroupLevel.DataBinding.Fields!GroupName.Value]"));

        return rt;
    }
 
    public bool IsReusable {
        get {
            return false;
        }
    }

}